@@ -6,7 +6,7 @@ use strict;
 use utf8;
 use warnings;
 
-our $VERSION = "2.003_2013881000";
+our $VERSION = "2.004_20131101";
 $VERSION = eval $VERSION;
 
 use Carp;
@@ -217,7 +217,7 @@ domain names). Use C<domain_to_unicode> instead.
 
 =item domain_to_ascii( $label, %param )
 
-Converts all labels of the hostname C<$domain> (with labels seperated by dots)
+Converts all labels of the hostname C<$domain> (with labels separated by dots)
 to ASCII (using C<to_ascii>). Will throw an exception on invalid input.
 
 This function takes the following optional parameters (C<%param>):
@@ -246,7 +246,7 @@ ideographic full stop).
 
 =item domain_to_unicode( $domain, %param )
 
-Converts all labels of the hostname C<$domain> (with labels seperated by dots)
+Converts all labels of the hostname C<$domain> (with labels separated by dots)
 to Unicode. Will throw an exception on invalid input.
 
 This function takes the same optional parameters as C<domain_to_ascii>,
